Description Usage Format Details Author(s) References
The package exports three data frames: css_unit_db,
latex_unit_db and latex_macro_db.
1 2 3 4 5 |
An object of class data.frame with 27 rows and 6 columns.
An object of class data.frame with 15 rows and 6 columns.
An object of class data.frame with 14 rows and 6 columns.
The format is not the same as the udunits2 database. Rows are:
symbol: symbol, e.g. "pt"
from_unit: unit on which the new unit is based, or NA
new: is unit new or already defined in udunits2?
remove: list-column of conflicting units to remove from udunits2
type: one of percent, length, angle, duration, frequency, resolution
Some units are redefined by "cssunits" so as to use a new symbol. For example, "arc_degree" is present in udunits2, but it is replaced by a new "deg" unit here.
David Hugh-Jones davidhughjones@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.