ex_half_em: Define ex = 0.5em

Description Usage Arguments Details Examples

Description

Define ex = 0.5em

Usage

1

Arguments

on

TRUE or FALSE to switch behaviour on or off.

Details

By default the package makes no assumption about the value of the length unit ex, which is font-dependent. Use this function to make an ex equal to 0.5em.

Examples

1
2
3
4
5
6
7
8
unloadNamespace("cssunits")
unloadNamespace("units")
library(cssunits)
library(units)

install_css_units()
ex_half_em()
set_units(1, "em") + set_units(1, "ex")

hughjonesd/cssunits documentation built on May 18, 2020, 12:56 p.m.