install_latex_units: Install length units for LaTeX

Description Usage Arguments Details Removing Examples

Description

Install length units for LaTeX

Usage

1

Arguments

macros

Boolean. Install some common LaTeX length macros such as \\textwidth?

Details

Some units will be removed from the standard udunits database, including "pt" (pint), "t" (tonne), "d" (day), "cc" (cubic centimeters), and "u" (unit of atomic mass).

Removing

These functions install incompatible versions of some units, e.g. CSS points are not the same as LaTeX points. They are also not idempotent: calling them twice will probably generate an error. To return to the pristine udunits2 database, use

1
2
3

Examples

1
2
3
4
5
6
unloadNamespace("cssunits")
unloadNamespace("units")
library(units)
library(cssunits)
install_latex_units()
set_units(1, "in") + set_units(72.27, "pt")

hughjonesd/cssunits documentation built on May 18, 2020, 12:56 p.m.