Description Usage Arguments Details Examples
Define ex = 0.5em
1 | ex_half_em(on = TRUE)
|
on |
|
By default the package makes no assumption about the value of the length unit ex, which is font-dependent. Use this function to make an ex equal to 0.5em.
1 2 3 4 5 6 7 8 | unloadNamespace("cssunits")
unloadNamespace("units")
library(cssunits)
library(units)
install_css_units()
ex_half_em()
set_units(1, "em") + set_units(1, "ex")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.