Description Usage Details Removing Examples
Install units for CSS
1 |
Some units will be removed from the standard database, including "pt" (pint), "t" (tonne), "pi" (the mathematical constant), "h" (hour), "rem" (unit of radiation).
These functions install incompatible versions of some units, e.g. CSS points are not the same as LaTeX points. They are also not idempotent: calling them twice will probably generate an error. To return to the pristine udunits2 database, use
1 2 3 | unloadNamespace("cssunits")
unloadNamespace("units")
library(units)
|
1 2 3 4 5 6 | unloadNamespace("cssunits")
unloadNamespace("units")
library(cssunits)
library(units)
install_css_units()
set_units(1, "in") + set_units(72, "pt")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.