Description Usage Arguments Details Removing Examples
Install length units for LaTeX
1 | install_latex_units(macros = FALSE)
|
macros |
Boolean. Install some common LaTeX length macros such
as |
Some units will be removed from the standard udunits database, including "pt" (pint), "t" (tonne), "d" (day), "cc" (cubic centimeters), and "u" (unit of atomic mass).
These functions install incompatible versions of some units, e.g. CSS points are not the same as LaTeX points. They are also not idempotent: calling them twice will probably generate an error. To return to the pristine udunits2 database, use
1 2 3 | unloadNamespace("cssunits")
unloadNamespace("units")
library(units)
|
1 2 3 4 5 6 | unloadNamespace("cssunits")
unloadNamespace("units")
library(units)
library(cssunits)
install_latex_units()
set_units(1, "in") + set_units(72.27, "pt")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.